@@ -3,19 +3,71 @@ if ! egrep "^\[PgLDAP\]"  /root/.odbc.ini >/dev/null 2>&1; then
   cat /etc/openldap/_odbc.ini >> /root/.odbc.ini
 fi
 ( cd usr/lib ; rm -rf liblber.so )
-( cd usr/lib ; ln -sf liblber-2.3.so.0.2.23 liblber.so )
+( cd usr/lib ; ln -sf liblber-2.3.so.0.2.27 liblber.so )
 ( cd usr/lib ; rm -rf liblber-2.3.so.0 )
-( cd usr/lib ; ln -sf liblber-2.3.so.0.2.23 liblber-2.3.so.0 )
+( cd usr/lib ; ln -sf liblber-2.3.so.0.2.27 liblber-2.3.so.0 )
 ( cd usr/lib ; rm -rf libldap.so )
-( cd usr/lib ; ln -sf libldap-2.3.so.0.2.23 libldap.so )
+( cd usr/lib ; ln -sf libldap-2.3.so.0.2.27 libldap.so )
 ( cd usr/lib ; rm -rf libldap-2.3.so.0 )
-( cd usr/lib ; ln -sf libldap-2.3.so.0.2.23 libldap-2.3.so.0 )
+( cd usr/lib ; ln -sf libldap-2.3.so.0.2.27 libldap-2.3.so.0 )
 ( cd usr/lib ; rm -rf libldap_r.so )
-( cd usr/lib ; ln -sf libldap_r-2.3.so.0.2.23 libldap_r.so )
+( cd usr/lib ; ln -sf libldap_r-2.3.so.0.2.27 libldap_r.so )
 ( cd usr/lib ; rm -rf libldap_r-2.3.so.0 )
-( cd usr/lib ; ln -sf libldap_r-2.3.so.0.2.23 libldap_r-2.3.so.0 )
+( cd usr/lib ; ln -sf libldap_r-2.3.so.0.2.27 libldap_r-2.3.so.0 )
 ( cd usr/bin ; rm -rf ldapadd )
 ( cd usr/bin ; ln -sf ldapmodify ldapadd )
+( cd usr/libexec/openldap ; rm -rf back_bdb.so )
+( cd usr/libexec/openldap ; ln -sf back_bdb-2.3.so.0.2.27 back_bdb.so )
+( cd usr/libexec/openldap ; rm -rf back_bdb-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_bdb-2.3.so.0.2.27 back_bdb-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_hdb.so )
+( cd usr/libexec/openldap ; ln -sf back_hdb-2.3.so.0.2.27 back_hdb.so )
+( cd usr/libexec/openldap ; rm -rf back_dnssrv-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_dnssrv-2.3.so.0.2.27 back_dnssrv-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_dnssrv.so )
+( cd usr/libexec/openldap ; ln -sf back_dnssrv-2.3.so.0.2.27 back_dnssrv.so )
+( cd usr/libexec/openldap ; rm -rf back_hdb-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_hdb-2.3.so.0.2.27 back_hdb-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_ldap.so )
+( cd usr/libexec/openldap ; ln -sf back_ldap-2.3.so.0.2.27 back_ldap.so )
+( cd usr/libexec/openldap ; rm -rf back_ldap-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_ldap-2.3.so.0.2.27 back_ldap-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_ldbm.so )
+( cd usr/libexec/openldap ; ln -sf back_ldbm-2.3.so.0.2.27 back_ldbm.so )
+( cd usr/libexec/openldap ; rm -rf back_ldbm-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_ldbm-2.3.so.0.2.27 back_ldbm-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_meta.so )
+( cd usr/libexec/openldap ; ln -sf back_meta-2.3.so.0.2.27 back_meta.so )
+( cd usr/libexec/openldap ; rm -rf back_meta-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_meta-2.3.so.0.2.27 back_meta-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_null.so )
+( cd usr/libexec/openldap ; ln -sf back_null-2.3.so.0.2.27 back_null.so )
+( cd usr/libexec/openldap ; rm -rf back_monitor-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_monitor-2.3.so.0.2.27 back_monitor-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_monitor.so )
+( cd usr/libexec/openldap ; ln -sf back_monitor-2.3.so.0.2.27 back_monitor.so )
+( cd usr/libexec/openldap ; rm -rf back_null-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_null-2.3.so.0.2.27 back_null-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_perl.so )
+( cd usr/libexec/openldap ; ln -sf back_perl-2.3.so.0.2.27 back_perl.so )
+( cd usr/libexec/openldap ; rm -rf back_passwd-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_passwd-2.3.so.0.2.27 back_passwd-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_passwd.so )
+( cd usr/libexec/openldap ; ln -sf back_passwd-2.3.so.0.2.27 back_passwd.so )
+( cd usr/libexec/openldap ; rm -rf back_perl-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_perl-2.3.so.0.2.27 back_perl-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_sql.so )
+( cd usr/libexec/openldap ; ln -sf back_sql-2.3.so.0.2.27 back_sql.so )
+( cd usr/libexec/openldap ; rm -rf back_relay-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_relay-2.3.so.0.2.27 back_relay-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_relay.so )
+( cd usr/libexec/openldap ; ln -sf back_relay-2.3.so.0.2.27 back_relay.so )
+( cd usr/libexec/openldap ; rm -rf back_shell-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_shell-2.3.so.0.2.27 back_shell-2.3.so.0 )
+( cd usr/libexec/openldap ; rm -rf back_shell.so )
+( cd usr/libexec/openldap ; ln -sf back_shell-2.3.so.0.2.27 back_shell.so )
+( cd usr/libexec/openldap ; rm -rf back_sql-2.3.so.0 )
+( cd usr/libexec/openldap ; ln -sf back_sql-2.3.so.0.2.27 back_sql-2.3.so.0 )
 ( cd usr/sbin ; rm -rf slapadd )
 ( cd usr/sbin ; ln -sf ../libexec/slapd slapadd )
 ( cd usr/sbin ; rm -rf slapcat )
